@@ -147,6 +147,7 @@ handle_get_user_information (XdpImplAccount        *object,
                              const char            *arg_parent_window,
                              GVariant              *arg_options)
 {
+  g_autoptr(GtkWindowGroup) window_group = NULL;
   g_autoptr(Request) request = NULL;
   const char *sender;
   AccountDialogHandle *handle;
@@ -155,7 +156,6 @@ handle_get_user_information (XdpImplAccount        *object,
   const char *icon_file;
   GtkWindow *dialog;
   GdkSurface *surface;
-  GdkDisplay *display;
   ExternalWindow *external_parent = NULL;
   GtkWidget *fake_parent;
   const char *reason;
@@ -179,20 +179,16 @@ handle_get_user_information (XdpImplAccount        *object,
                    arg_parent_window);
     }
 
-  if (external_parent)
-    display = external_window_get_display (external_parent);
-  else
-    display = gdk_display_get_default ();
-
-  fake_parent = g_object_new (GTK_TYPE_WINDOW,
-                              "display", display,
-                              NULL);
+  fake_parent = g_object_new (GTK_TYPE_WINDOW, NULL);
   g_object_ref_sink (fake_parent);
 
   dialog = GTK_WINDOW (account_dialog_new (arg_app_id, user_name, real_name, icon_file, reason));
   gtk_window_set_transient_for (dialog, GTK_WINDOW (fake_parent));
   gtk_window_set_modal (dialog, TRUE);
 
+  window_group = gtk_window_group_new ();
+  gtk_window_group_add_window (window_group, dialog);
+
   handle = g_new0 (AccountDialogHandle, 1);
   handle->impl = object;
   handle->invocation = invocation;
@@ -213,7 +209,7 @@ handle_get_user_information (XdpImplAccount        *object,
   if (external_parent)
     external_window_set_parent_of (external_parent, surface);
 
-  gtk_widget_show (GTK_WIDGET (dialog));
+  gtk_window_present (dialog);
 
   request_export (request, g_dbus_method_invocation_get_connection (invocation));
 
