@@ -147,6 +147,7 @@ handle_choose_application (XdpImplAppChooser *object,
                            const char **choices,
                            GVariant *arg_options)
 {
+  g_autoptr(GtkWindowGroup) window_group = NULL;
   g_autoptr(Request) request = NULL;
   GtkWindow *dialog;
   AppDialogHandle *handle;
@@ -186,9 +187,11 @@ handle_choose_application (XdpImplAppChooser *object,
 
   dialog = GTK_WINDOW (app_chooser_dialog_new (choices, latest_chosen_id, content_type, location));
   gtk_window_set_transient_for (dialog, GTK_WINDOW (fake_parent));
-
   gtk_window_set_modal (dialog, modal);
 
+  window_group = gtk_window_group_new ();
+  gtk_window_group_add_window (window_group, dialog);
+
   handle = g_new0 (AppDialogHandle, 1);
   handle->impl = object;
   handle->invocation = invocation;
