@@ -249,22 +249,9 @@ init_x11_interop (GdkDisplay *display)
     g_debug ("Missing X11 interop protocol support");
 }
 
-static void
-on_service_channel_name_appeared (GDBusConnection *connection,
-                                  const char      *name,
-                                  const char      *name_owner,
-                                  gpointer         user_data)
-{
-  gboolean *name_appeared = user_data;
-
-  *name_appeared = TRUE;
-}
-
 GdkDisplay *
 init_external_window_wayland_display (GError **error)
 {
-  guint watch_name_id;
-  gboolean name_appeared = FALSE;
   g_autoptr(OrgGnomeMutterServiceChannel) proxy = NULL;
   g_autoptr(GVariant) fd_variant = NULL;
   g_autoptr(GUnixFDList) fd_list = NULL;
@@ -272,17 +259,6 @@ init_external_window_wayland_display (GError **error)
   g_autofree char *fd_str = NULL;
   GdkDisplay *display;
 
-  watch_name_id =
-    g_bus_watch_name (G_BUS_TYPE_SESSION,
-                      "org.gnome.Mutter.ServiceChannel",
-                      G_BUS_NAME_WATCHER_FLAGS_NONE,
-                      on_service_channel_name_appeared,
-                      NULL,
-                      &name_appeared, NULL);
-  while (!name_appeared)
-    g_main_context_iteration (NULL, TRUE);
-  g_bus_unwatch_name (watch_name_id);
-
   proxy = org_gnome_mutter_service_channel_proxy_new_for_bus_sync (
     G_BUS_TYPE_SESSION,
     (G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START |
