@@ -30,6 +30,7 @@ struct _Session
   gboolean exported;
   gboolean closed;
   char *id;
+  char *peer_name;
 };
 
 struct _SessionClass
@@ -54,3 +55,9 @@ gboolean session_export (Session *session,
                          GError **error);
 
 void session_unexport (Session *session);
+
+const char * session_get_peer_name (Session *session);
+
+const char * session_get_id (Session *session);
+
+void session_emit_closed (Session *session);
